import * as i0 from '@angular/core';
import { Injectable, EventEmitter, Component, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpClientModule } from '@angular/common/http';
import * as i2 from '@angular/material/tabs';
import { MatTabsModule } from '@angular/material/tabs';
import * as i3 from '@angular/material/grid-list';
import { MatGridListModule } from '@angular/material/grid-list';
import * as i4 from '@angular/material/card';
import { MatCardModule } from '@angular/material/card';
import * as i5 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import { MatInputModule } from '@angular/material/input';
import { MatFormFieldModule } from '@angular/material/form-field';
import { RouterModule } from '@angular/router';

class ReportsService {
    constructor(httpClient) {
        this.httpClient = httpClient;
    }
    loadGroups() {
        return this.httpClient.get(`/rpt/groups`);
    }
    listReportsByGroupId(groupId) {
        return this.httpClient.get(`/rpt/report/group/${groupId}`);
    }
    getReportWithFilters(reportId) {
        return this.httpClient.get(`/rpt/report/${reportId}`);
    }
}
ReportsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, deps: [{ token: i1.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
ReportsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.HttpClient }]; } });

class ReportsComponent {
    constructor(reportService) {
        this.reportService = reportService;
        this.reportsGroups = [];
        this.reportsByGroupId = [];
        this.$subs = [];
        this.onViewClicked = new EventEmitter();
        this.breakpoint = 2;
        this.selectedIndex = 0;
    }
    ngOnInit() {
        this.loadGroups();
    }
    loadGroups() {
        const sub1 = this.reportService.loadGroups().subscribe(res => {
            this.reportsGroups = res;
            this.$subs.push(sub1);
        });
    }
    listReportsByGroupId(groupId) {
        const sub2 = this.reportService.listReportsByGroupId(groupId).subscribe(res2 => {
            this.reportsByGroupId = res2;
        });
        this.$subs.push(sub2);
    }
    ;
    onTabChanged(event) {
        this.listReportsByGroupId(this.reportsGroups[event].id);
    }
    viewReportFilterDetails(report) {
        this.onViewClicked.emit(report);
    }
    ngOnDestroy() {
        this.$subs.forEach((item) => item.unsubscribe());
    }
}
ReportsComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsComponent, deps: [{ token: ReportsService }], target: i0.ɵɵFactoryTarget.Component });
ReportsComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.16", type: ReportsComponent, selector: "lib-reports-groups", outputs: { onViewClicked: "onViewClicked" }, ngImport: i0, template: `

    <mat-tab-group *ngIf="reportsGroups" (selectedIndexChange)="onTabChanged($event)">
      <mat-tab  [id]="group.id" *ngFor="let group of reportsGroups;let i=index" label="{{group.name}}" >
        <mat-grid-list class="mt-2" [cols]="breakpoint"  rowHeight="200px">
          <mat-grid-tile *ngFor="let report of reportsByGroupId">
            <mat-card class="example-card" >
              <mat-card-title>{{report.name}}</mat-card-title>
              <mat-card-content>
                <p>{{report.descreption}}</p>
              </mat-card-content>
              <mat-card-actions>
                <button mat-button class="viewButton" (click)="viewReportFilterDetails(report)">View</button>
              </mat-card-actions>
            </mat-card>
          </mat-grid-tile>
        </mat-grid-list>

      </mat-tab>
    </mat-tab-group>



  `, isInline: true, components: [{ type: i2.MatTabGroup, selector: "mat-tab-group", inputs: ["color", "disableRipple"], exportAs: ["matTabGroup"] }, { type: i2.MatTab, selector: "mat-tab", inputs: ["disabled", "label", "aria-label", "aria-labelledby"], exportAs: ["matTab"] }, { type: i3.MatGridList, selector: "mat-grid-list", inputs: ["cols", "gutterSize", "rowHeight"], exportAs: ["matGridList"] }, { type: i3.MatGridTile, selector: "mat-grid-tile", inputs: ["rowspan", "colspan"], exportAs: ["matGridTile"] }, { type: i4.MatCard, selector: "mat-card", exportAs: ["matCard"] }, { type: i5.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }], directives: [{ type: i4.MatCardTitle, selector: "mat-card-title, [mat-card-title], [matCardTitle]" }, { type: i4.MatCardContent, selector: "mat-card-content, [mat-card-content], [matCardContent]" }, { type: i4.MatCardActions, selector: "mat-card-actions", inputs: ["align"], exportAs: ["matCardActions"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'lib-reports-groups',
                    template: `

    <mat-tab-group *ngIf="reportsGroups" (selectedIndexChange)="onTabChanged($event)">
      <mat-tab  [id]="group.id" *ngFor="let group of reportsGroups;let i=index" label="{{group.name}}" >
        <mat-grid-list class="mt-2" [cols]="breakpoint"  rowHeight="200px">
          <mat-grid-tile *ngFor="let report of reportsByGroupId">
            <mat-card class="example-card" >
              <mat-card-title>{{report.name}}</mat-card-title>
              <mat-card-content>
                <p>{{report.descreption}}</p>
              </mat-card-content>
              <mat-card-actions>
                <button mat-button class="viewButton" (click)="viewReportFilterDetails(report)">View</button>
              </mat-card-actions>
            </mat-card>
          </mat-grid-tile>
        </mat-grid-list>

      </mat-tab>
    </mat-tab-group>



  `,
                    styles: []
                }]
        }], ctorParameters: function () { return [{ type: ReportsService }]; }, propDecorators: { onViewClicked: [{
                type: Output
            }] } });

// import {MatInputModule} from "../../../../";
// import {MatInputModule} from "@angular/material/input";
class ReportsModule {
}
ReportsModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ReportsModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, declarations: [ReportsComponent], imports: [MatInputModule,
        MatFormFieldModule,
        MatTabsModule,
        MatGridListModule,
        MatCardModule,
        MatButtonModule,
        HttpClientModule,
        RouterModule], exports: [ReportsComponent] });
ReportsModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, imports: [[
            MatInputModule,
            MatFormFieldModule,
            MatTabsModule,
            MatGridListModule,
            MatCardModule,
            MatButtonModule,
            HttpClientModule,
            RouterModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.16", ngImport: i0, type: ReportsModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        ReportsComponent
                    ],
                    imports: [
                        MatInputModule,
                        MatFormFieldModule,
                        MatTabsModule,
                        MatGridListModule,
                        MatCardModule,
                        MatButtonModule,
                        HttpClientModule,
                        RouterModule
                    ],
                    exports: [
                        ReportsComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of reports
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ReportsComponent, ReportsModule, ReportsService };
//# sourceMappingURL=reports-hyper74.js.map
